@@ -12,7 +12,7 @@ var searchData=
   ['juce_5fhandlexembedevent_9',['juce_handleXEmbedEvent',['../group__juce__gui__extra-embedding.html#ga2cad300cf70fc35a54a9a260022017a9',1,'juce_XEmbedComponent.h']]],
   ['juce_5fhypot_10',['juce_hypot',['../group__juce__core-maths.html#ga18cf7a25c960a8c2b10cd4ea914eae75',1,'juce_MathsFunctions.h']]],
   ['juce_5fiosurlsessionnotify_11',['juce_iosURLSessionNotify',['../classURL_1_1DownloadTask.html#ab39eab9c0eacb9bdf99bd8c905781a9b',1,'URL::DownloadTask']]],
-  ['juce_5fisfinite_12',['juce_isfinite',['../group__juce__core-maths.html#ga715cf75caf01f50c8bdad7a8a919db3a',1,'juce_isfinite(NumericType) noexcept:&#160;juce_MathsFunctions.h'],['../group__juce__core-maths.html#ga6e2771eca3bab30735064a25b5909d03',1,'juce_isfinite(float value) noexcept:&#160;juce_MathsFunctions.h'],['../group__juce__core-maths.html#gab2876c74abd3981e46841e94a4b3ae67',1,'juce_isfinite(double value) noexcept:&#160;juce_MathsFunctions.h']]],
+  ['juce_5fisfinite_12',['juce_isfinite',['../group__juce__core-maths.html#gad7192293b8adb577a09854094a108918',1,'juce_MathsFunctions.h']]],
   ['juceapplication_13',['JUCEApplication',['../classJUCEApplication.html#a80e6dadf35b6954df90f2e11bb25ad8b',1,'JUCEApplication']]],
   ['juceapplicationbase_14',['JUCEApplicationBase',['../classJUCEApplicationBase.html#a3b64c47474ca9bf96c4ad7c0ee8cb3f5',1,'JUCEApplicationBase']]],
   ['jucesplashscreen_15',['JUCESplashScreen',['../classJUCESplashScreen.html#ace2db6a7a5b1219e3ec5163978242495',1,'JUCESplashScreen']]],
